// ABBYY ® Mobile Imaging UI Components © 2018 ABBYY Production LLC.
// ABBYY is either a registered trademark or a trademark of ABBYY Software Ltd.

package com.abbyy.mobile.sample.imagecapture;

import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.GridLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;

import com.abbyy.mobile.sample.imagecapture.image.ImageUtils;
import com.abbyy.mobile.sample.imagecapture.multipage.PagesAdapter;

/**
 * Main activity of the app displays already captured pages.
 * Each page is stored in a separate file, pages are split into two
 * directories - pages/ and add_pages/. Pages captured during the current
 * capture session are stored in add_pages/ and moved to pages/ when
 * the session is finished.
 */
public class MainActivity extends AppCompatActivity {

	// This code is used to request pages from CaptureActivity
	private static final int PAGES_REQUEST_CODE = 0;

	// Adapter for pages' recycler view
	private PagesAdapter pagesAdapter;

	private ImageView emptyDocumentView;
	private Button captureAddPages;

	@Override
	protected void onCreate( Bundle savedInstanceState )
	{
		super.onCreate( savedInstanceState );
		setContentView( R.layout.activity_main );

		emptyDocumentView = findViewById( R.id.emptyDocument );
		TextView buildNumberView = findViewById( R.id.buildNumber );
		// retrieve build number of UI Components SDK
		buildNumberView.setText( getString( R.string.build_number, com.abbyy.mobile.uicomponents.BuildConfig.VERSION_NAME ) );

		Button captureNewPages = findViewById( R.id.captureNew );
		captureNewPages.setOnClickListener( new View.OnClickListener() {
			@Override
			public void onClick( View v )
			{
				ImageUtils.clearPages( MainActivity.this );
				pagesAdapter.releasePages();
				emptyDocumentView.setVisibility( View.VISIBLE );
				captureAddPages.setVisibility( View.GONE );
				startCapture();
			}
		} );
		int pagesCount = ImageUtils.getPageCount( this );
		captureAddPages = findViewById( R.id.captureAdd );
		captureAddPages.setOnClickListener( new View.OnClickListener() {
			@Override
			public void onClick( View v )
			{
				startCapture();
			}
		} );
		if( pagesCount > 0 ) {
			emptyDocumentView.setVisibility( View.GONE );
			captureAddPages.setVisibility( View.VISIBLE );
		}
		RecyclerView pagesView = findViewById( R.id.pages );
		pagesView.setHasFixedSize( true );

		RecyclerView.LayoutManager layoutManager = new GridLayoutManager( this,
			getResources().getInteger( R.integer.columns_count ) );
		pagesView.setLayoutManager( layoutManager );
		pagesAdapter = new PagesAdapter( pagesCount );
		pagesView.setAdapter( pagesAdapter );
	}

	private void startCapture()
	{
		Intent intent = new Intent( MainActivity.this, CaptureActivity.class );
		startActivityForResult( intent, PAGES_REQUEST_CODE );
	}

	@Override
	protected void onActivityResult( int requestCode, int resultCode, @Nullable Intent data )
	{
		if( requestCode == PAGES_REQUEST_CODE ) {
			if( resultCode == RESULT_OK ) {
				int pagesCount = ImageUtils.getPageCount( this );
				pagesAdapter.updatePagesCount( pagesCount );
				if( pagesCount > 0 ) {
					emptyDocumentView.setVisibility( View.GONE );
					captureAddPages.setVisibility( View.VISIBLE );
				}
			}
		}
	}
}
