package com.abbyy.mobile.sample.imagecapture.multipage;

import android.content.Context;
import android.graphics.Bitmap;
import android.support.annotation.NonNull;
import android.util.AttributeSet;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;

import com.abbyy.mobile.sample.imagecapture.R;
import com.abbyy.mobile.sample.imagecapture.image.ImageLoader;
import com.abbyy.mobile.sample.imagecapture.image.ImageUtils;

import java.io.File;
import java.io.IOException;

/**
 * Auxiliary class for the view that displays the current session's page count
 * and the miniature of the last captured page (loads it if necessary)
 * and serves as a button to finish current capture session
 */
public class MultiPageCounter extends FrameLayout {
	private ImageView lastPageMiniatureView;
	private TextView pageCounter;
	private ImageLoader lastPageMiniatureLoader;

	public MultiPageCounter( Context context )
	{
		super( context );
		init();
	}

	public MultiPageCounter( Context context, AttributeSet attrs )
	{
		super( context, attrs );
		init();
	}

	public MultiPageCounter( Context context, AttributeSet attrs, int defStyleAttr )
	{
		super( context, attrs, defStyleAttr );
		init();
	}

	public MultiPageCounter( Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes )
	{
		super( context, attrs, defStyleAttr, defStyleRes );
		init();
	}

	private void init()
	{
		inflate( getContext(), R.layout.page_counter, this );
		lastPageMiniatureView = findViewById( R.id.lastPage );
		pageCounter = findViewById( R.id.pageCounter );
	}

	public void updateUI( int sessionCapturePageCount, Bitmap lastPage )
	{
		if( sessionCapturePageCount == 0 ) {
			setVisibility( View.GONE );
			return;
		}
		Bitmap lastPageMiniature = null;
		if( lastPage != null ) {
			// Create last page miniature
			lastPageMiniature = ImageUtils.getMiniature(
				lastPage,
				getResources().getDimensionPixelSize( R.dimen.miniature_size )
			);
		}
		if( lastPageMiniature == null ) {
			loadMiniature( sessionCapturePageCount );
		} else {
			setLastPageMiniature( lastPageMiniature );
		}
		pageCounter.setText( String.valueOf( sessionCapturePageCount ) );
		setVisibility( View.VISIBLE );
	}

	private void setLastPageMiniature( Bitmap lastPageMiniature )
	{
		lastPageMiniatureView.setImageDrawable( ImageUtils.getRoundedImage( getContext(), lastPageMiniature ) );
	}

	private void loadMiniature( final int sessionCapturePageCount )
	{
		String lastPagePath = ImageUtils.getCaptureSessionPageFile( sessionCapturePageCount - 1, getContext() ).getPath();
		lastPageMiniatureLoader = new ImageLoader( lastPagePath, new ImageLoader.Callback() {
			@Override
			public Bitmap loadBitmap( @NonNull File file ) throws IOException
			{
				return ImageUtils.loadThumbnail(
					file,
					getResources().getDimensionPixelSize( R.dimen.miniature_size )
				);
			}

			@Override
			public void onImageReady( @NonNull Bitmap image )
			{
				setLastPageMiniature( image );
			}

			@Override
			public void onError( @NonNull Exception error )
			{
				setLastPageMiniature( null );
			}
		} );
		lastPageMiniatureLoader.execute();
	}

	public void cancelLoad()
	{
		if( lastPageMiniatureLoader != null ) {
			lastPageMiniatureLoader.cancel( true );
		}
	}
}
